OptionCode

Enum OptionCode 

#[repr(u16)]
pub enum OptionCode {
Show 18 variants LLQ = 1, UL = 2, NSID = 3, DAU = 5, DHU = 6, N3U = 7, EDNSCLIENTSUBNET = 8, EDNSEXPIRE = 9, COOKIE = 10, EDNSTCPKEEPALIVE = 11, PADDING = 12, CHAIN = 13, EDNSKEYTAG = 14, EDNSERROR = 15, EDNSCLIENTTAG = 16, EDNSSERVERTAG = 17, DEVICEID = 26_946, UNKNOWN = 26947,
}

Variants



LLQ = 1

Long-Lived Queries



UL = 2

Update Leases



NSID = 3

Name Server Identifier



DAU = 5

DNSSEC Algorithm Understood



DHU = 6

DS Hash Understood



N3U = 7

NSEC3 Hash Understood



EDNSCLIENTSUBNET = 8

EDNS0 option to allow Recursive Resolvers, if they are willing, to forward details about the origin network from which a query is coming when talking to other nameservers



EDNSEXPIRE = 9

See https://tools.ietf.org/html/rfc7314



COOKIE = 10

See https://tools.ietf.org/html/rfc7873#section-4



EDNSTCPKEEPALIVE = 11

Signals a variable idle timeout



PADDING = 12

Allows DNS clients and servers to pad requests and responses by a variable number of octets



CHAIN = 13

Allows a security-aware validating resolver to send a single query requesting a complete validation path along with the regular answer



EDNSKEYTAG = 14

Provides origin authentication using digital signatures



EDNSERROR = 15

Returning additional information about the cause of DNS errors



EDNSCLIENTTAG = 16

Draft, usage is being determined. See https://www.ietf.org/archive/id/draft-bellis-dnsop-edns-tags-01.txt



EDNSSERVERTAG = 17

Draft, usage is being determined. See https://www.ietf.org/archive/id/draft-bellis-dnsop-edns-tags-01.txt



DEVICEID = 26_946

A way of identifying a device via DNS in the OPT RDATA



UNKNOWN = 26947

Implementations

Source

impl OptionCode

pub fn from_raw(val: u16) -> Self