OptResponseCode

Enum OptResponseCode 

#[repr(u16)]
pub enum OptResponseCode {
Show 14 variants NOERROR = 0, FORMATERROR = 1, SERVERFAILURE = 2, NAMEERROR = 3, NOTIMPLEMENTED = 4, REFUSED = 5, YXDOMAIN = 6, YXRRSET = 7, NXRRSET = 8, NOTAUTH = 9, NOTZONE = 10, BADVERSION = 16, BADCOOKIE = 23, UNKNOWN = 24,
}

Variants



NOERROR = 0

No error condition.



FORMATERROR = 1

The name server was unable to interpret the query.



SERVERFAILURE = 2

There was a problem with the name server.



NAMEERROR = 3

The domain name referenced in the query does not exist.



NOTIMPLEMENTED = 4

The name server does not support the requested kind of query.



REFUSED = 5

The name server’s policy forbids providing this information.



YXDOMAIN = 6

Name exists when it should not.



YXRRSET = 7

RR set exists when it should not.



NXRRSET = 8

RR set that should exist does not.



NOTAUTH = 9

Server not authoritative for zone or client not authorized.



NOTZONE = 10

Name not in contained zone.



BADVERSION = 16

Bad OPT version



BADCOOKIE = 23

Bad/missing server cookie



UNKNOWN = 24

Implementations

Source

impl OptResponseCode

pub fn from_raw(val: u16) -> Self